.. _moduleref_cet:

.. index::
   single: Function reference; User interface; icet
   single: Class reference; User interface; icet

:program:`icet`
***************

.. toctree::
   :maxdepth: 2
   :caption: Contents

   cluster_space
   structure_container
   cluster_expansion
   tools
